@@ -22,8 +22,6 @@
 
 #include <glib.h>
 
-#include <gconf/gconf-glib-public.h>
-
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -32,7 +30,7 @@ extern "C" {
 
 /* Error Numbers */
 
-/* Sync with ConfigErrorType in GConf.idl, and some switch statements in the code */
+/* Sync with ConfigErrorType in GConf.idl */
 typedef enum {
   GCONF_ERROR_SUCCESS = 0,
   GCONF_ERROR_FAILED = 1,        /* Something didn't work, don't know why, probably unrecoverable
