@@ -57,7 +57,7 @@ gconf_schema_free(GConfSchema* sc)
 }
 
 GConfSchema*  
-gconf_schema_copy(GConfSchema* sc)
+gconf_schema_copy(const GConfSchema* sc)
 {
   GConfSchema* dest;
 
@@ -162,7 +162,7 @@ gconf_schema_set_owner(GConfSchema* sc, const gchar* owner)
 }
 
 void
-gconf_schema_set_default_value(GConfSchema* sc, GConfValue* val)
+gconf_schema_set_default_value(GConfSchema* sc, const GConfValue* val)
 {
   if (sc->default_value != NULL)
     gconf_value_free(sc->default_value);
@@ -180,8 +180,8 @@ gconf_schema_set_default_value_nocopy(GConfSchema* sc, GConfValue* val)
 }
 
 gboolean
-gconf_schema_validate (GConfSchema *sc,
-                       GError     **err)
+gconf_schema_validate (const GConfSchema *sc,
+                       GError           **err)
 {
   if (sc->locale && !g_utf8_validate (sc->locale, -1, NULL))
     {
